@@ -18,8 +18,9 @@ sub handler : method
 {
   my ($class, $r) = @_;
   
-  $ENV{DOCUMENT_ROOT} = $r->document_root;
-  $ENV{REMOTE_ADDR} = $r->connection->get_remote_host();
+  $ENV{DOCUMENT_ROOT} ||= $r->document_root;
+  $ENV{REMOTE_ADDR}     = $r->connection->get_remote_host();
+  $ENV{HTTP_HOST}       = $r->hostname;
   my $context = ASP4::HTTPContext->new();
   
   if( uc($r->method) eq 'POST' && $r->headers_in->{'content-type'} =~ m/multipart\/form\-data/ )
